@@ -126,9 +126,7 @@ class NWPML(DataSourceOutputML):
         xr_dataset = re_order_dims(xr_dataset)
 
         # convert to torch dict
-        nwp_batch_ml = xr_dataset.torch.to_tensor(
-            ["data", "time", "init_time", "x", "y"]
-        )
+        nwp_batch_ml = xr_dataset.torch.to_tensor(["data", "time", "init_time", "x", "y"])
 
         # make into Model
         return NWPML(**nwp_batch_ml)
